@@ -21,7 +21,7 @@ def procdf(function,allvars,procaxis,dimidx=0):
             dataout.append(dtotmp)
     else:
         # workaround for memory leak when just running  'dataouttemp = function(allvars)' in case of netcdf file references
-        allvarstmp = []
+        allvarstemp = []
         for evar in allvars:
             allvarstemp.append(array(evar))
         dataouttemp = function(allvarstemp)
